# Distributed under the terms of the GNU General Public License v2

EAPI=7

inherit gnome3 readme.gentoo-r1 meson

DESCRIPTION="Archive manager for GNOME"
HOMEPAGE="https://wiki.gnome.org/Apps/FileRoller"

LICENSE="GPL-2+ CC-BY-SA-3.0"
SLOT="0"
IUSE="libnotify nautilus packagekit"
KEYWORDS="*"

# gdk-pixbuf used extensively in the source
# cairo used in eggtreemultidnd.c
# pango used in fr-window
# meson 0.48.0 is broken https://github.com/mesonbuild/meson/issues/4257
RDEPEND="
	|| ( >=dev-util/meson-0.48.1 <dev-util/meson-0.48.0 )
	>=app-arch/libarchive-3:=
	>=dev-libs/glib-2.62.2:2
	>=dev-libs/json-glib-0.14
	>=x11-libs/gtk+-3.24.12:3
	sys-apps/file
	x11-libs/cairo
	x11-libs/gdk-pixbuf:2
	x11-libs/pango
	libnotify? ( >=x11-libs/libnotify-0.4.3:= )
	nautilus? ( >=gnome-base/nautilus-3 )
	packagekit? ( app-admin/packagekit-base )
"
DEPEND="${RDEPEND}
	>=dev-util/intltool-0.50.1
	dev-util/itstool
	sys-devel/gettext
	virtual/pkgconfig
"

DISABLE_AUTOFORMATTING="yes"
DOC_CONTENTS="
${PN} is a frontend for several archiving utilities. If you want a
particular archive format support, see ${HOMEPAGE}
and install the relevant package. For example:
7-zip   - app-arch/p7zip
ace     - app-arch/unace
arj     - app-arch/arj
cpio    - app-arch/cpio
deb     - app-arch/dpkg
iso     - app-cdr/cdrtools
jar,zip - app-arch/zip and app-arch/unzip
lha     - app-arch/lha
lzop    - app-arch/lzop
rar     - app-arch/unrar or app-arch/unar
rpm     - app-arch/rpm
unstuff - app-arch/stuffit
zoo     - app-arch/zoo"

src_prepare() {
	# File providing Gentoo package names for various archivers
	cp -f "${FILESDIR}"/3.22-packages.match data/packages.match || die
	gnome3_src_prepare
}

src_configure() {
	local emesonargs=(
		$(meson_use nautilus nautilus-actions)
		$(meson_use libnotify notification)
		$(meson_use packagekit)
	)

	meson_src_configure
}
