# Distributed under the terms of the GNU General Public License v2

EAPI=7
GNOME3_LA_PUNT="yes"
PYTHON_COMPAT=( python3+ )

inherit gnome3 python-single-r1 virtualx meson

DESCRIPTION="A GObject plugins library"
HOMEPAGE="https://developer.gnome.org/libpeas/stable/"

LICENSE="LGPL-2+"
SLOT="0"
KEYWORDS="*"

IUSE="doc demos +gtk glade +introspection lua +python vala"
REQUIRED_USE="python? ( ${PYTHON_REQUIRED_USE} )"

RDEPEND="
	>=dev-libs/glib-2.62.2:2
	>=dev-libs/gobject-introspection-1.62.0:=
	glade? ( >=dev-util/glade-3.9.1:3.10 )
	gtk? ( >=x11-libs/gtk+-3:3[introspection] )
	lua? (
		>=dev-lua/lgi-0.9.0
		=dev-lang/lua-5.1*:0 )
	python? (
		${PYTHON_DEPS}
		$(python_gen_cond_dep '>=dev-python/pygobject-3.2:3[${PYTHON_USEDEP}]') )
"
DEPEND="${RDEPEND}
	>=dev-util/gtk-doc-am-1.11
	>=dev-util/intltool-0.40
	virtual/pkgconfig

	dev-libs/gobject-introspection-common
	gnome-base/gnome-common
"
# eautoreconf needs gobject-introspection-common, gnome-common

pkg_setup() {
	use python && python-single-r1_pkg_setup
}

src_prepare() {
	sed -i "s@subdir('introspection')@generate_gir ? subdir('introspection') :@" tests/libpeas/meson.build
	gnome3_src_prepare
}

src_configure() {
	# Wtf, --disable-gcov, --enable-gcov=no, --enable-gcov, all enable gcov
	# What do we do about gdb, valgrind, gcov, etc?
	local emesonargs=(
		$(meson_use glade glade_catalog)
		$(meson_use gtk widgetry)

		# py2 not supported anymore
		-Dpython2=false
		$(meson_use python python3)

		# lua
		$(meson_use lua lua51)

		$(meson_use doc gtk_doc)
		$(meson_use demos)
		$(meson_use introspection)
		$(meson_use vala vapi)
	)

	meson_src_configure "${myconf[@]}"
}

src_test() {
	# This looks fixed since 1.18.0:
	#
	# FIXME: Tests fail because of some bug involving Xvfb and Gtk.IconTheme
	# DO NOT REPORT UPSTREAM, this is not a libpeas bug.
	# To reproduce:
	# >>> from gi.repository import Gtk
	# >>> Gtk.IconTheme.get_default().has_icon("gtk-about")
	# This should return True, it returns False for Xvfb
	virtx emake check
}
