# Distributed under the terms of the GNU General Public License v2

EAPI=7
PYTHON_COMPAT=( python3+ )

CMAKE_ECLASS=cmake
inherit cmake flag-o-matic mono-env python-r1

DESCRIPTION="Library for automatic proxy configuration management"
HOMEPAGE="https://github.com/libproxy/libproxy"
SRC_URI="https://github.com/libproxy/libproxy/tarball/caccaf28e3df6ea612d2d4b39f781c4324019fdb -> libproxy-0.4.18-caccaf2.tar.gz"

LICENSE="LGPL-2.1+"
SLOT="0"
KEYWORDS="*"
IUSE="gnome kde mono networkmanager perl python spidermonkey webkit"
REQUIRED_USE="python? ( ${PYTHON_REQUIRED_USE} )"

BDEPEND="
	virtual/pkgconfig
"
DEPEND="
	gnome? ( dev-libs/glib:2 )
	mono? ( dev-lang/mono )
	networkmanager? ( sys-apps/dbus:0 )
	spidermonkey? ( dev-lang/spidermonkey:68 )
	webkit? ( net-libs/webkit-gtk:4 )
"
RDEPEND="${DEPEND}
	kde? ( kde-frameworks/kconfig:5 )
"
# avoid dependency loop, bug #467696
PDEPEND="networkmanager? ( net-misc/networkmanager )"

PATCHES=(
	# prevent dependency loop with networkmanager, libsoup, glib-networking; bug #467696
	# https://github.com/libproxy/libproxy/issues/28
	"${FILESDIR}/${PN}-0.4.18-avoid-nm-build-dep.patch"
)

src_unpack() {
	unpack ${A}
	mv ${WORKDIR}/libproxy-libproxy-* ${S} || die
}

src_prepare() {
	cmake_src_prepare
	# see FL-6535:
	sed -i -e 's/test prove/test_perl prove/g' ${S}/bindings/perl/t/CMakeLists.txt || die
}

src_configure() {
	local mycmakeargs=(
		-DCMAKE_C_FLAGS="${CFLAGS}"
		-DCMAKE_CXX_FLAGS="${CXXFLAGS}"
		-DWITH_NATUS=OFF
		-DWITH_PYTHON2=OFF
		# WITH_VALA just copies the .vapi file over and needs no deps,
		# hence always enable it unconditionally
		-DWITH_VALA=ON
		-DWITH_WEBKIT=OFF
		$(usex mono -DGMCS_EXECUTABLE="${EPREFIX}"/usr/bin/mcs)
		-DWITH_GNOME3=$(usex gnome)
		-DWITH_KDE=$(usex kde)
		-DWITH_DOTNET=$(usex mono || echo OFF)
		-DWITH_NM=$(usex networkmanager)
		-DWITH_PERL=$(usex perl || echo OFF)
		-DWITH_PYTHON3=ON
		-DWITH_MOZJS=$(usex spidermonkey || echo OFF)
		-DWITH_WEBKIT3=$(usex webkit || echo OFF)
	)
	cmake_src_configure
}